@@ -14,7 +14,7 @@ use App::Sqitch::Types qw(Str Int Sqitch Plan Bool HashRef URI Maybe Target);
 use namespace::autoclean;
 use constant registry_release => '1.0';
 
-our $VERSION = '0.998';
+our $VERSION = '0.999';
 
 has sqitch => (
     is       => 'ro',
@@ -30,6 +30,8 @@ has target => (
     weak_ref => 1,
     handles => {
         uri         => 'uri',
+        username    => 'username',
+        password    => 'password',
         client      => 'client',
         registry    => 'registry',
         destination => 'name',
@@ -180,7 +182,7 @@ sub deploy {
     } elsif ($plan->position == -1) {
         # Initialize or upgrade the database, if necessary.
         if ($self->initialized) {
-            $self->upgrade_registry if $self->needs_upgrade;
+            $self->upgrade_registry;
         } else {
             $sqitch->info(__x(
                 'Adding registry tables to {destination}',
@@ -195,7 +197,7 @@ sub deploy {
         hurl deploy => __ 'Cannot deploy to an earlier change; use "revert" instead'
             if $to_index < $plan->position;
         # Upgrade database if it needs it.
-        $self->upgrade_registry if $self->needs_upgrade;
+        $self->upgrade_registry;
     }
 
     $sqitch->info(
@@ -837,6 +839,13 @@ sub _sync_plan {
             $change = $plan->change_at($idx);
         }
 
+        # Upgrade the registry if there is no script_hash column.
+        unless ( exists $state->{script_hash} ) {
+            $self->upgrade_registry;
+            $state->{script_hash} = $state->{change_id};
+        }
+
+        # Update the script hashes if they're the same as the change ID.
         $self->_update_script_hashes if $state->{script_hash}
             && $state->{script_hash} eq $state->{change_id};
 
