@@ -2,6 +2,20 @@ BEGIN;
 
 SET SESSION sql_mode = ansi;
 
+CREATE TABLE releases (
+    version         FLOAT         PRIMARY KEY
+                    COMMENT 'Version of the Sqitch registry.',
+    installed_at    TIMESTAMP     NOT NULL
+                    COMMENT 'Date the registry release was installed.',
+    installer_name  VARCHAR(255)  NOT NULL
+                    COMMENT 'Name of the user who installed the registry release.',
+    installer_email VARCHAR(255)  NOT NULL
+                    COMMENT 'Email address of the user who installed the registry release.'
+) ENGINE  InnoDB,
+  CHARACTER SET 'utf8',
+  COMMENT 'Sqitch registry releases.'
+;
+
 CREATE TABLE projects (
     project         VARCHAR(255) PRIMARY KEY
                     COMMENT 'Unique Name of a project.',
@@ -21,6 +35,8 @@ CREATE TABLE projects (
 CREATE TABLE changes (
     change_id       VARCHAR(40)  PRIMARY KEY
                     COMMENT 'Change primary key.',
+    script_hash     VARCHAR(40)      NULL UNIQUE
+                    COMMENT 'Deploy script SHA-1 hash.',
     "change"        VARCHAR(255) NOT NULL
                     COMMENT 'Name of a deployed change.',
     project         VARCHAR(255) NOT NULL
@@ -94,7 +110,7 @@ CREATE TABLE dependencies (
 ;
 
 CREATE TABLE events (
-    event           ENUM ('deploy', 'fail', 'revert') NOT NULL
+    event           ENUM ('deploy', 'fail', 'merge', 'revert') NOT NULL
                     COMMENT 'Type of event.',
     change_id       VARCHAR(40)  NOT NULL
                     COMMENT 'Change ID.',
