@@ -5,6 +5,19 @@ CREATE SCHEMA :"registry";
 
 COMMENT ON SCHEMA :"registry" IS 'Sqitch database deployment metadata v1.0.';
 
+CREATE TABLE :"registry".releases (
+    version         REAL        PRIMARY KEY,
+    installed_at    TIMESTAMPTZ NOT NULL DEFAULT clock_timestamp(),
+    installer_name  TEXT        NOT NULL,
+    installer_email TEXT        NOT NULL
+);
+
+COMMENT ON TABLE  :"registry".releases                 IS 'Sqitch registry releases.';
+COMMENT ON COLUMN :"registry".releases.version         IS 'Version of the Sqitch registry.';
+COMMENT ON COLUMN :"registry".releases.installed_at    IS 'Date the registry release was installed.';
+COMMENT ON COLUMN :"registry".releases.installer_name  IS 'Name of the user who installed the registry release.';
+COMMENT ON COLUMN :"registry".releases.installer_email IS 'Email address of the user who installed the registry release.';
+
 CREATE TABLE :"registry".projects (
     project         TEXT        PRIMARY KEY,
     uri             TEXT            NULL UNIQUE,
@@ -13,7 +26,7 @@ CREATE TABLE :"registry".projects (
     creator_email   TEXT        NOT NULL
 ):tableopts;
 
-COMMENT ON TABLE :"registry".projects                 IS 'Sqitch projects deployed to this database.';
+COMMENT ON TABLE  :"registry".projects                IS 'Sqitch projects deployed to this database.';
 COMMENT ON COLUMN :"registry".projects.project        IS 'Unique Name of a project.';
 COMMENT ON COLUMN :"registry".projects.uri            IS 'Optional project URI';
 COMMENT ON COLUMN :"registry".projects.created_at     IS 'Date the project was added to the database.';
@@ -22,6 +35,7 @@ COMMENT ON COLUMN :"registry".projects.creator_email  IS 'Email address of the u
 
 CREATE TABLE :"registry".changes (
     change_id       TEXT        PRIMARY KEY,
+    script_hash     TEXT            NULL UNIQUE,
     change          TEXT        NOT NULL,
     project         TEXT        NOT NULL REFERENCES :"registry".projects(project) ON UPDATE CASCADE,
     note            TEXT        NOT NULL DEFAULT '',
@@ -33,8 +47,9 @@ CREATE TABLE :"registry".changes (
     planner_email   TEXT        NOT NULL
 ):tableopts;
 
-COMMENT ON TABLE :"registry".changes                  IS 'Tracks the changes currently deployed to the database.';
+COMMENT ON TABLE  :"registry".changes                 IS 'Tracks the changes currently deployed to the database.';
 COMMENT ON COLUMN :"registry".changes.change_id       IS 'Change primary key.';
+COMMENT ON COLUMN :"registry".changes.script_hash     IS 'Deploy script SHA-1 hash.';
 COMMENT ON COLUMN :"registry".changes.change          IS 'Name of a deployed change.';
 COMMENT ON COLUMN :"registry".changes.project         IS 'Name of the Sqitch project to which the change belongs.';
 COMMENT ON COLUMN :"registry".changes.note            IS 'Description of the change.';
@@ -60,7 +75,7 @@ CREATE TABLE :"registry".tags (
     UNIQUE(project, tag)
 ):tableopts;
 
-COMMENT ON TABLE :"registry".tags                  IS 'Tracks the tags currently applied to the database.';
+COMMENT ON TABLE  :"registry".tags                 IS 'Tracks the tags currently applied to the database.';
 COMMENT ON COLUMN :"registry".tags.tag_id          IS 'Tag primary key.';
 COMMENT ON COLUMN :"registry".tags.tag             IS 'Project-unique tag name.';
 COMMENT ON COLUMN :"registry".tags.project         IS 'Name of the Sqitch project to which the tag belongs.';
@@ -84,14 +99,14 @@ CREATE TABLE :"registry".dependencies (
     PRIMARY KEY (change_id, dependency)
 ):tableopts;
 
-COMMENT ON TABLE :"registry".dependencies                IS 'Tracks the currently satisfied dependencies.';
+COMMENT ON TABLE  :"registry".dependencies               IS 'Tracks the currently satisfied dependencies.';
 COMMENT ON COLUMN :"registry".dependencies.change_id     IS 'ID of the depending change.';
 COMMENT ON COLUMN :"registry".dependencies.type          IS 'Type of dependency.';
 COMMENT ON COLUMN :"registry".dependencies.dependency    IS 'Dependency name.';
 COMMENT ON COLUMN :"registry".dependencies.dependency_id IS 'Change ID the dependency resolves to.';
 
 CREATE TABLE :"registry".events (
-    event           TEXT        NOT NULL CHECK (event IN ('deploy', 'revert', 'fail')),
+    event           TEXT        NOT NULL CHECK (event IN ('deploy', 'revert', 'fail', 'merge')),
     change_id       TEXT        NOT NULL,
     change          TEXT        NOT NULL,
     project         TEXT        NOT NULL REFERENCES :"registry".projects(project) ON UPDATE CASCADE,
@@ -108,7 +123,7 @@ CREATE TABLE :"registry".events (
     PRIMARY KEY (change_id, committed_at)
 ):tableopts;
 
-COMMENT ON TABLE :"registry".events                  IS 'Contains full history of all deployment events.';
+COMMENT ON TABLE  :"registry".events                 IS 'Contains full history of all deployment events.';
 COMMENT ON COLUMN :"registry".events.event           IS 'Type of event.';
 COMMENT ON COLUMN :"registry".events.change_id       IS 'Change ID.';
 COMMENT ON COLUMN :"registry".events.change          IS 'Change name.';
