@@ -12,7 +12,7 @@ use App::Sqitch::Types qw(DBH ArrayRef);
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.998';
+our $VERSION = '0.999';
 
 sub key    { 'vertica' }
 sub name   { 'Vertica' }
@@ -32,7 +32,7 @@ sub destination {
     $uri->password(undef) if $uri->password;
     $uri->dbname(
            $ENV{VSQL_DATABASE}
-        || $uri->user
+        || $self->username
         || $ENV{VSQL_USER}
         || $self->sqitch->sysuser
     );
@@ -48,10 +48,10 @@ has _vsql => (
         my $uri  = $self->uri;
         my @ret  = ( $self->client );
         for my $spec (
-            [ username => $uri->user   ],
-            [ dbname   => $uri->dbname ],
-            [ host     => $uri->host   ],
-            [ port     => $uri->_port  ],
+            [ username => $self->username ],
+            [ dbname   => $uri->dbname    ],
+            [ host     => $uri->host      ],
+            [ port     => $uri->_port     ],
             )
         {
             push @ret, "--$spec->[0]" => $spec->[1] if $spec->[1];
@@ -84,13 +84,15 @@ has dbh => (
         $self->use_driver;
 
         # Set defaults in the URI.
+        my $target = $self->target;
         my $uri = $self->uri;
         # https://my.vertica.com/docs/5.1.6/HTML/index.htm#2736.htm
         $uri->dbname($ENV{VSQL_DATABASE})   if !$uri->dbname   && $ENV{VSQL_DATABASE};
         $uri->host($ENV{VSQL_HOST})         if !$uri->host     && $ENV{VSQL_HOST};
         $uri->port($ENV{VSQL_PORT})         if !$uri->_port    && $ENV{VSQL_PORT};
         $uri->user($ENV{VSQL_USER})         if !$uri->user     && $ENV{VSQL_USER};
-        $uri->password($ENV{VSQL_PASSWORD}) if !$uri->password && $ENV{VSQL_PASSWORD};
+        $uri->password($target->password || $ENV{VSQL_PASSWORD})
+            if !$uri->password && ($target->password || $ENV{VSQL_PASSWORD});
 
         DBI->connect($uri->dbi_dsn, scalar $uri->user, scalar $uri->password, {
             PrintError        => 0,
@@ -192,6 +194,10 @@ sub _no_table_error  {
     return $DBI::state && $DBI::state eq '42V01'; # ERRCODE_UNDEFINED_TABLE
 }
 
+sub _no_column_error  {
+    return $DBI::state && $DBI::state eq '42703'; # ERRCODE_UNDEFINED_COLUMN
+}
+
 sub _ts2char($) {
     my $col = shift;
     return qq{to_char($col AT TIME ZONE 'UTC', '"year":YYYY:"month":MM:"day":DD:"hour":HH24:"minute":MI:"second":SS:"time_zone":"UTC"')};
@@ -245,31 +251,37 @@ sub _tag_subselect_columns {
     );
 }
 
-sub current_state {
-    my ( $self, $project ) = @_;
+sub _select_state {
+    my ( $self, $project, $with_hash ) = @_;
     my $cdtcol = sprintf $self->_ts2char_format, 'c.committed_at';
     my $pdtcol = sprintf $self->_ts2char_format, 'c.planned_at';
+    my $hshcol = $with_hash ? "c.script_hash\n             , " : '';
+    return $self->dbh->selectrow_hashref(qq{
+        SELECT c.change_id
+             , ${hshcol}c.change
+             , c.project
+             , c.note
+             , c.committer_name
+             , c.committer_email
+             , $cdtcol AS committed_at
+             , c.planner_name
+             , c.planner_email
+             , $pdtcol AS planned_at
+          FROM changes c
+         WHERE c.project = ?
+         ORDER BY c.committed_at DESC
+         LIMIT 1
+    }, undef, $project // $self->plan->project );
+}
+
+sub current_state {
+    my ( $self, $project ) = @_;
     my $dbh    = $self->dbh;
     my $state  = try {
-        $dbh->selectrow_hashref(qq{
-            SELECT c.change_id
-                 , c.script_hash
-                 , c.change
-                 , c.project
-                 , c.note
-                 , c.committer_name
-                 , c.committer_email
-                 , $cdtcol AS committed_at
-                 , c.planner_name
-                 , c.planner_email
-                 , $pdtcol AS planned_at
-              FROM changes c
-             WHERE c.project = ?
-             ORDER BY c.committed_at DESC
-             LIMIT 1
-        }, undef, $project // $self->plan->project );
+        $self->_select_state($project, 1)
     } catch {
         return if $self->_no_table_error && !$self->initialized;
+        return $self->_select_state($project, 0) if $self->_no_column_error;
         die $_;
     } or return undef;
 
@@ -469,8 +481,7 @@ sub name_for_change_id {
 sub _run {
     my $self   = shift;
     my $sqitch = $self->sqitch;
-    my $uri    = $self->uri;
-    my $pass   = $uri->password or return $sqitch->run( $self->vsql, @_ );
+    my $pass   = $self->password or return $sqitch->run( $self->vsql, @_ );
     local $ENV{VSQL_PASSWORD} = $pass;
     return $sqitch->run( $self->vsql, @_ );
 }
@@ -478,8 +489,7 @@ sub _run {
 sub _capture {
     my $self   = shift;
     my $sqitch = $self->sqitch;
-    my $uri    = $self->uri;
-    my $pass   = $uri->password or return $sqitch->capture( $self->vsql, @_ );
+    my $pass   = $self->password or return $sqitch->capture( $self->vsql, @_ );
     local $ENV{VSQL_PASSWORD} = $pass;
     return $sqitch->capture( $self->vsql, @_ );
 }
@@ -487,8 +497,7 @@ sub _capture {
 sub _probe {
     my $self   = shift;
     my $sqitch = $self->sqitch;
-    my $uri    = $self->uri;
-    my $pass   = $uri->password or return $sqitch->probe( $self->vsql, @_ );
+    my $pass   = $self->password or return $sqitch->probe( $self->vsql, @_ );
     local $ENV{VSQL_PASSWORD} = $pass;
     return $sqitch->probe( $self->vsql, @_ );
 }
@@ -497,8 +506,7 @@ sub _spool {
     my $self   = shift;
     my $fh     = shift;
     my $sqitch = $self->sqitch;
-    my $uri    = $self->uri;
-    my $pass   = $uri->password or return $sqitch->spool( $fh, $self->vsql, @_ );
+    my $pass   = $self->password or return $sqitch->spool( $fh, $self->vsql, @_ );
     local $ENV{VSQL_PASSWORD} = $pass;
     return $sqitch->spool( $fh, $self->vsql, @_ );
 }
