@@ -35,7 +35,13 @@ my $punct = q{-!"#$%&'()*+,./:;<=>?@[\\]^`{|}~};
 sub _dbsymtag($) {
     # Return LAST or FIRST if it is a DB symbolic tag.
     $_[0] =~ /\A[@]?((?:LA|FIR)ST)(?:(?<![$punct])([~^])(?:(\2)|(\d+))?)?\z/ or return;
-    return $1;
+    my $t = $1;
+    App::Sqitch->warn(__x(
+        'The @{old} symbolic tag has been deprecated; use @{new} instead',
+        old => $t,
+        new => $t eq 'LAST' ? 'HEAD' : 'ROOT',
+    ));
+    return $t;
 }
 
 sub _offset($) {
@@ -54,7 +60,7 @@ sub _lookup {
     my $symtag = _dbsymtag $key or return $self->{lookup}{$key};
     # XXX The rest of this only applies to the deprecated @FIRST & @LAST tags.
     my $change = $self->{list}[0] || return undef;
-    my $engine = $change->plan->sqitch->engine;
+    my $engine = $change->plan->target->engine;
     my $offset = _offset $key;
     $key = do {
         if ($symtag eq 'LAST') {
